GpuTextureFormat enum

Texture formats.

See WebGPU spec: GPUTextureFormat.

Inheritance
Available extensions

Values

r8Unorm → const GpuTextureFormat

1-channel, 8-bit unsigned normalized.

r8Snorm → const GpuTextureFormat

1-channel, 8-bit signed normalized.

r8Uint → const GpuTextureFormat

1-channel, 8-bit unsigned integer.

r8Sint → const GpuTextureFormat

1-channel, 8-bit signed integer.

r16Uint → const GpuTextureFormat

1-channel, 16-bit unsigned integer.

r16Sint → const GpuTextureFormat

1-channel, 16-bit signed integer.

r16Float → const GpuTextureFormat

1-channel, 16-bit float.

r16Unorm → const GpuTextureFormat

1-channel, 16-bit unsigned normalized.

r16Snorm → const GpuTextureFormat

1-channel, 16-bit signed normalized.

rg8Unorm → const GpuTextureFormat

2-channel, 8-bit per channel unsigned normalized.

rg8Snorm → const GpuTextureFormat

2-channel, 8-bit per channel signed normalized.

rg8Uint → const GpuTextureFormat

2-channel, 8-bit per channel unsigned integer.

rg8Sint → const GpuTextureFormat

2-channel, 8-bit per channel signed integer.

r32Uint → const GpuTextureFormat

1-channel, 32-bit unsigned integer.

r32Sint → const GpuTextureFormat

1-channel, 32-bit signed integer.

r32Float → const GpuTextureFormat

1-channel, 32-bit float.

rg16Uint → const GpuTextureFormat

2-channel, 16-bit per channel unsigned integer.

rg16Sint → const GpuTextureFormat

2-channel, 16-bit per channel signed integer.

rg16Float → const GpuTextureFormat

2-channel, 16-bit per channel float.

rg16Unorm → const GpuTextureFormat

2-channel, 16-bit per channel unsigned normalized.

rg16Snorm → const GpuTextureFormat

2-channel, 16-bit per channel signed normalized.

rgba8Unorm → const GpuTextureFormat

4-channel, 8-bit per channel unsigned normalized.

rgba8UnormSrgb → const GpuTextureFormat

4-channel, 8-bit per channel unsigned normalized (sRGB).

rgba8Snorm → const GpuTextureFormat

4-channel, 8-bit per channel signed normalized.

rgba8Uint → const GpuTextureFormat

4-channel, 8-bit per channel unsigned integer.

rgba8Sint → const GpuTextureFormat

4-channel, 8-bit per channel signed integer.

bgra8Unorm → const GpuTextureFormat

4-channel BGRA, 8-bit per channel unsigned normalized.

bgra8UnormSrgb → const GpuTextureFormat

4-channel BGRA, 8-bit per channel unsigned normalized (sRGB).

rgb9e5UFloat → const GpuTextureFormat

3-channel, packed 9/9/9-bit with 5-bit shared exponent, unsigned float.

rgb10a2Uint → const GpuTextureFormat

4-channel, packed 10/10/10/2-bit unsigned integer.

rgb10a2Unorm → const GpuTextureFormat

4-channel, packed 10/10/10/2-bit unsigned normalized.

rg11b10UFloat → const GpuTextureFormat

3-channel, packed 11/11/10-bit unsigned float.

rg32Uint → const GpuTextureFormat

2-channel, 32-bit per channel unsigned integer.

rg32Sint → const GpuTextureFormat

2-channel, 32-bit per channel signed integer.

rg32Float → const GpuTextureFormat

2-channel, 32-bit per channel float.

rgba16Uint → const GpuTextureFormat

4-channel, 16-bit per channel unsigned integer.

rgba16Sint → const GpuTextureFormat

4-channel, 16-bit per channel signed integer.

rgba16Float → const GpuTextureFormat

4-channel, 16-bit per channel float.

rgba16Unorm → const GpuTextureFormat

4-channel, 16-bit per channel unsigned normalized.

rgba16Snorm → const GpuTextureFormat

4-channel, 16-bit per channel signed normalized.

rgba32Uint → const GpuTextureFormat

4-channel, 32-bit per channel unsigned integer.

rgba32Sint → const GpuTextureFormat

4-channel, 32-bit per channel signed integer.

rgba32Float → const GpuTextureFormat

4-channel, 32-bit per channel float.

stencil8 → const GpuTextureFormat

8-bit stencil only.

depth16Unorm → const GpuTextureFormat

16-bit depth, unsigned normalized.

depth24Plus → const GpuTextureFormat

24-bit depth (implementation-chosen format, at least 24 bits).

depth24PlusStencil8 → const GpuTextureFormat

24-bit depth + 8-bit stencil.

depth32Float → const GpuTextureFormat

32-bit depth, float.

depth32FloatStencil8 → const GpuTextureFormat

32-bit float depth + 8-bit stencil. Requires "depth32float-stencil8".

bc1RgbaUnorm → const GpuTextureFormat

BC1 RGBA unsigned normalized (4 bpp).

bc1RgbaUnormSrgb → const GpuTextureFormat

BC1 RGBA unsigned normalized sRGB (4 bpp).

bc2RgbaUnorm → const GpuTextureFormat

BC2 RGBA unsigned normalized (8 bpp).

bc2RgbaUnormSrgb → const GpuTextureFormat

BC2 RGBA unsigned normalized sRGB (8 bpp).

bc3RgbaUnorm → const GpuTextureFormat

BC3 RGBA unsigned normalized (8 bpp).

bc3RgbaUnormSrgb → const GpuTextureFormat

BC3 RGBA unsigned normalized sRGB (8 bpp).

bc4RUnorm → const GpuTextureFormat

BC4 single-channel unsigned normalized (4 bpp).

bc4RSnorm → const GpuTextureFormat

BC4 single-channel signed normalized (4 bpp).

bc5RgUnorm → const GpuTextureFormat

BC5 two-channel unsigned normalized (8 bpp).

bc5RgSnorm → const GpuTextureFormat

BC5 two-channel signed normalized (8 bpp).

bc6hRgbUFloat → const GpuTextureFormat

BC6H three-channel unsigned float (8 bpp, HDR).

bc6hRgbFloat → const GpuTextureFormat

BC6H three-channel signed float (8 bpp, HDR).

bc7RgbaUnorm → const GpuTextureFormat

BC7 RGBA unsigned normalized (8 bpp).

bc7RgbaUnormSrgb → const GpuTextureFormat

BC7 RGBA unsigned normalized sRGB (8 bpp).

etc2Rgb8Unorm → const GpuTextureFormat

ETC2 RGB unsigned normalized (4 bpp).

etc2Rgb8UnormSrgb → const GpuTextureFormat

ETC2 RGB unsigned normalized sRGB (4 bpp).

etc2Rgb8a1Unorm → const GpuTextureFormat

ETC2 RGB + 1-bit alpha unsigned normalized (4 bpp).

etc2Rgb8a1UnormSrgb → const GpuTextureFormat

ETC2 RGB + 1-bit alpha unsigned normalized sRGB (4 bpp).

etc2Rgba8Unorm → const GpuTextureFormat

ETC2 RGBA unsigned normalized (8 bpp).

etc2Rgba8UnormSrgb → const GpuTextureFormat

ETC2 RGBA unsigned normalized sRGB (8 bpp).

eacR11Unorm → const GpuTextureFormat

EAC single-channel unsigned normalized (4 bpp).

eacR11Snorm → const GpuTextureFormat

EAC single-channel signed normalized (4 bpp).

eacRg11Unorm → const GpuTextureFormat

EAC two-channel unsigned normalized (8 bpp).

eacRg11Snorm → const GpuTextureFormat

EAC two-channel signed normalized (8 bpp).

astc4x4Unorm → const GpuTextureFormat

ASTC 4x4 block unsigned normalized.

astc4x4UnormSrgb → const GpuTextureFormat

ASTC 4x4 block unsigned normalized sRGB.

astc5x4Unorm → const GpuTextureFormat

ASTC 5x4 block unsigned normalized.

astc5x4UnormSrgb → const GpuTextureFormat

ASTC 5x4 block unsigned normalized sRGB.

astc5x5Unorm → const GpuTextureFormat

ASTC 5x5 block unsigned normalized.

astc5x5UnormSrgb → const GpuTextureFormat

ASTC 5x5 block unsigned normalized sRGB.

astc6x5Unorm → const GpuTextureFormat

ASTC 6x5 block unsigned normalized.

astc6x5UnormSrgb → const GpuTextureFormat

ASTC 6x5 block unsigned normalized sRGB.

astc6x6Unorm → const GpuTextureFormat

ASTC 6x6 block unsigned normalized.

astc6x6UnormSrgb → const GpuTextureFormat

ASTC 6x6 block unsigned normalized sRGB.

astc8x5Unorm → const GpuTextureFormat

ASTC 8x5 block unsigned normalized.

astc8x5UnormSrgb → const GpuTextureFormat

ASTC 8x5 block unsigned normalized sRGB.

astc8x6Unorm → const GpuTextureFormat

ASTC 8x6 block unsigned normalized.

astc8x6UnormSrgb → const GpuTextureFormat

ASTC 8x6 block unsigned normalized sRGB.

astc8x8Unorm → const GpuTextureFormat

ASTC 8x8 block unsigned normalized.

astc8x8UnormSrgb → const GpuTextureFormat

ASTC 8x8 block unsigned normalized sRGB.

astc10x5Unorm → const GpuTextureFormat

ASTC 10x5 block unsigned normalized.

astc10x5UnormSrgb → const GpuTextureFormat

ASTC 10x5 block unsigned normalized sRGB.

astc10x6Unorm → const GpuTextureFormat

ASTC 10x6 block unsigned normalized.

astc10x6UnormSrgb → const GpuTextureFormat

ASTC 10x6 block unsigned normalized sRGB.

astc10x8Unorm → const GpuTextureFormat

ASTC 10x8 block unsigned normalized.

astc10x8UnormSrgb → const GpuTextureFormat

ASTC 10x8 block unsigned normalized sRGB.

astc10x10Unorm → const GpuTextureFormat

ASTC 10x10 block unsigned normalized.

astc10x10UnormSrgb → const GpuTextureFormat

ASTC 10x10 block unsigned normalized sRGB.

astc12x10Unorm → const GpuTextureFormat

ASTC 12x10 block unsigned normalized.

astc12x10UnormSrgb → const GpuTextureFormat

ASTC 12x10 block unsigned normalized sRGB.

astc12x12Unorm → const GpuTextureFormat

ASTC 12x12 block unsigned normalized.

astc12x12UnormSrgb → const GpuTextureFormat

ASTC 12x12 block unsigned normalized sRGB.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GpuTextureFormat>
A constant List of the values in this enum, in order of their declaration.