WgpuResource class abstract interface

Base interface for GPU resources that require explicit cleanup.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this resource has been disposed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Release native resources. Safe to call multiple times.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disposeAll(List<WgpuResource> resources) → void
Disposes all resources in reverse order (LIFO).