WGPUAdapterInfo class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUAdapterInfo()

Properties

adapter_type int
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
architecture Pointer<Char>
getter/setter pair
backend_type int
getter/setter pair
description Pointer<Char>
getter/setter pair
device Pointer<Char>
getter/setter pair
device_id int
getter/setter pair
driver_api_version int
Vulkan API version (VK_MAKE_API_VERSION packed u32), 0 on non-Vulkan.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vendor Pointer<Char>
getter/setter pair
vendor_id int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited