WGPUComputePassDescriptor class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
label
↔ Pointer<
Char> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp_writes_beginning ↔ int
-
Query index for beginning timestamp.
getter/setter pair
- timestamp_writes_end ↔ int
-
Query index for end timestamp.
getter/setter pair
- timestamp_writes_query_set ↔ int
-
Timestamp writes query set handle (0 = none).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited