WGPUComputePipelineDescriptor class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
constant_count int
Number of pipeline-overridable constants.
getter/setter pair
constant_keys Pointer<Pointer<Char>>
Parallel array of constant key C-strings (length = constant_count).
getter/setter pair
constant_values Pointer<Double>
Parallel array of constant f64 values (length = constant_count).
getter/setter pair
entry_point Pointer<Char>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label Pointer<Char>
getter/setter pair
layout int
getter/setter pair
module int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited