WGPUDepthStencilState class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUDepthStencilState()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
depth_bias int
getter/setter pair
depth_bias_clamp double
getter/setter pair
depth_bias_slope_scale double
getter/setter pair
depth_compare int
getter/setter pair
depth_write_enabled int
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stencil_back_compare int
getter/setter pair
stencil_back_depth_fail_op int
getter/setter pair
stencil_back_fail_op int
getter/setter pair
stencil_back_pass_op int
getter/setter pair
stencil_front_compare int
getter/setter pair
stencil_front_depth_fail_op int
getter/setter pair
stencil_front_fail_op int
getter/setter pair
stencil_front_pass_op int
getter/setter pair
stencil_read_mask int
getter/setter pair
stencil_write_mask int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited