WGPUInstanceDescriptor class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUInstanceDescriptor()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
backends int
Backend bitmask: Vulkan=1, GL=2, Metal=4, DX12=8, BrowserWebGpu=16. 0 = all backends (default).
getter/setter pair
gpu_based_validation int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validation int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited