WGPURenderBundleEncoderDescriptor class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
color_format_count int
getter/setter pair
color_formats Pointer<Uint32>
getter/setter pair
depth_read_only int
getter/setter pair
depth_stencil_format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label Pointer<Char>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_count int
getter/setter pair
stencil_read_only int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited