WGPURenderPassColorAttachment class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
clear_a double
getter/setter pair
clear_b double
getter/setter pair
clear_g double
getter/setter pair
clear_r double
getter/setter pair
depth_slice int
Depth slice for 3D texture render targets (u32::MAX = None).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
load_op int
getter/setter pair
resolve_target int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store_op int
getter/setter pair
view int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited