WGPURenderPassDescriptor class final

Inheritance
Implemented types
Available extensions

Constructors

WGPURenderPassDescriptor()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
color_attachment_count int
getter/setter pair
color_attachments Pointer<WGPURenderPassColorAttachment>
getter/setter pair
depth_stencil_attachment Pointer<WGPURenderPassDepthStencilAttachment>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label Pointer<Char>
getter/setter pair
max_draw_count int
Max draw calls (0 = use default 50_000_000).
getter/setter pair
occlusion_query_set int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp_writes_beginning int
Query index for beginning timestamp.
getter/setter pair
timestamp_writes_end int
Query index for end timestamp.
getter/setter pair
timestamp_writes_query_set int
Timestamp writes query set handle (0 = none).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited