WGPURenderPipelineDescriptor class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
alpha_to_coverage_enabled int
getter/setter pair
cull_mode int
getter/setter pair
depth_stencil WGPUDepthStencilState
getter/setter pair
depth_stencil_enabled int
getter/setter pair
fragment WGPUFragmentState
getter/setter pair
front_face int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label Pointer<Char>
getter/setter pair
layout int
getter/setter pair
multisample_count int
getter/setter pair
multisample_mask int
getter/setter pair
primitive_topology int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strip_index_format int
getter/setter pair
unclipped_depth int
getter/setter pair
vertex WGPUVertexState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited