WGPUTextureDescriptor class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUTextureDescriptor()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
depth_or_array_layers int
getter/setter pair
dimension int
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
label Pointer<Char>
getter/setter pair
mip_level_count int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_count int
getter/setter pair
usage int
getter/setter pair
view_format_count int
getter/setter pair
view_formats Pointer<Uint32>
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited