WGPUTextureViewDescriptor class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUTextureViewDescriptor()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
array_layer_count int
getter/setter pair
aspect int
getter/setter pair
base_array_layer int
getter/setter pair
base_mip_level int
getter/setter pair
dimension int
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label Pointer<Char>
getter/setter pair
mip_level_count int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage int
TextureUsages flags (0 = inherit from texture).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited