wgpu_get_pixel_buffer_ptr function
Get the pixel buffer pointer for a surface (Windows only).
Implementation
@ffi.Native<ffi.Pointer<ffi.Uint8> Function(ffi.Uint64)>()
external ffi.Pointer<ffi.Uint8> wgpu_get_pixel_buffer_ptr(
int surface_id,
);
Get the pixel buffer pointer for a surface (Windows only).
@ffi.Native<ffi.Pointer<ffi.Uint8> Function(ffi.Uint64)>()
external ffi.Pointer<ffi.Uint8> wgpu_get_pixel_buffer_ptr(
int surface_id,
);