wgpu_swapchain_get_depth_view function
Get the depth texture view for a swapchain surface.
Implementation
@ffi.Native<ffi.Uint64 Function(ffi.Uint64)>()
external int wgpu_swapchain_get_depth_view(
int surface_id,
);
Get the depth texture view for a swapchain surface.
@ffi.Native<ffi.Uint64 Function(ffi.Uint64)>()
external int wgpu_swapchain_get_depth_view(
int surface_id,
);