wgpun_DevicePopErrorScope function

  1. @Native<Uint32 Function(Uint64)>(ffi.Uint64)>()
int wgpun_DevicePopErrorScope(
  1. int device
)

Pop the top error scope and return the error type + message. Returns error type: 0 = no error, 1 = Validation, 2 = OutOfMemory, 3 = Internal. If an error was captured, the message is available via wgpun_DevicePopScopeError.

Implementation

@ffi.Native<ffi.Uint32 Function(ffi.Uint64)>()
external int wgpun_DevicePopErrorScope(
  int device,
);