WGPUDeviceDescriptor class final

Inheritance
Implemented types
Available extensions

Constructors

WGPUDeviceDescriptor()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bindless_textures int
If non-zero, request bindless texture extensions (wgpu-specific).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
immediates int
If non-zero, request IMMEDIATES feature (push constants).
getter/setter pair
label Pointer<Char>
getter/setter pair
required_features int
Bitmask of required features (bit positions match GpuFeatureName enum order).
getter/setter pair
required_limits Pointer<WGPUDeviceLimits>
Pointer to required limits, or null for defaults.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited