WGPUSamplerDescriptor class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - address_mode_u ↔ int
-
getter/setter pair
- address_mode_v ↔ int
-
getter/setter pair
- address_mode_w ↔ int
-
getter/setter pair
- compare ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
label
↔ Pointer<
Char> -
getter/setter pair
- lod_max_clamp ↔ double
-
getter/setter pair
- lod_min_clamp ↔ double
-
getter/setter pair
- mag_filter ↔ int
-
getter/setter pair
- max_anisotropy ↔ int
-
getter/setter pair
- min_filter ↔ int
-
getter/setter pair
- mipmap_filter ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited